<?php

namespace App\Http\Controllers;

use App\Models\Formulario;
use Illuminate\Http\Request;
use PDF;
use Carbon\Carbon;

/**
 * Class FormularioController
 * @package App\Http\Controllers
 */
class FormularioController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $formularios = Formulario::paginate(20);

        return view('formulario.index', compact('formularios'))
            ->with('i', (request()->input('page', 1) - 1) * $formularios->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $formulario = new Formulario();
        return view('formulario.create', compact('formulario'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Formulario::$rules);

        $formulario = Formulario::create($request->all());

        return redirect()->route('formularios.index')
            ->with('success', 'Formulario creado satisfactoriamente.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $formulario = Formulario::find($id);

        return view('formulario.show', compact('formulario'));
    }

    // para buscar formularios por nombre
    public function buscar(Request $request)
    {
       $formularios = Formulario::where('nombre','like', '%'.$request->buscarFor.'%')->paginate(20);
       return view('formulario.index', compact('formularios'))
       ->with('i', (request()->input('page', 1) - 1) * $formularios->perPage());
    }

    // para generar PDF listado de formularios
    public function createForPDF()
    {
       $formularios = Formulario::all();
       view()->share('formuarios', $formularios);
       $pdf = PDF::loadView('formulario.pdf',compact('formularios'))->setOptions(['defaultFont' => 'sans-serif']);
       return $pdf->download('formularios.pdf');

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $formulario = Formulario::find($id);

        return view('formulario.edit', compact('formulario'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Formulario $formulario
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Formulario $formulario)
    {
        request()->validate(Formulario::$rules);

        $formulario->update($request->all());

        return redirect()->route('formularios.index')
            ->with('success', 'Formulario updated successfully');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $formulario = Formulario::find($id)->delete();

        return redirect()->route('formularios.index')
            ->with('Eliminar', 'Ok');

    }

    // para descargar la guía .pdf de FADEMA
    // la guía se encuentra almacenada en emconsulta/public/guias/guia1.pdf
    public function descargar($id)
    {
        $formulario = Formulario::find($id);
        $nombre=$formulario->nombre;
        $file= public_path(). "/guias/".$nombre.".pdf";
        return response()->download($file);
    }
}
