<?php

namespace App\Http\Controllers;

use App\Models\Paciente;
use Illuminate\Http\Request;
use PDF;
use Carbon\Carbon;

/**
 * Class PacienteController
 * @package App\Http\Controllers
 */
class PacienteController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $pacientes = Paciente::paginate(20);// número de registros a mostrar por página

        return view('paciente.index', compact('pacientes'))
            ->with('i', (request()->input('page', 1) - 1) * $pacientes->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $paciente = new Paciente();
        return view('paciente.create', compact('paciente'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Paciente::$rules);

        $paciente = Paciente::create($request->all());

        return redirect()->route('pacientes.index')
            ->with('success', 'Paciente creado satisfactoriamente.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $paciente = Paciente::find($id);

        return view('paciente.show', compact('paciente'));
    }

    // para mostrar el gráfico
    public function grafico($id)
    {
        $paciente = Paciente::find($id);
        return view('paciente.grafico', compact('paciente'));
    }

     // para generar PDF gráficos de un paciente
     public function createGraficoPDF($id)
     {
        $paciente = Paciente::find($id);
       return $paciente;
 
     }
 
    // para buscar un paciente por nombre
    public function buscar(Request $request)
    {
       $pacientes = Paciente::where('name','like', '%'.$request->buscarPac.'%')->paginate(20);
       return view('paciente.index', compact('pacientes'))
       ->with('i', (request()->input('page', 1) - 1) * $pacientes->perPage());
    }
  
   // para generar PDF listado de pacientes
    public function createPDF()
    {
       $pacientes = Paciente::all();
       view()->share('pacientes', $pacientes);
       $pdf = PDF::loadView('paciente.pdf',compact('pacientes'))->setOptions(['defaultFont' => 'sans-serif']); 
       return $pdf->download('pacientes.pdf');

    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $paciente = Paciente::find($id);

        return view('paciente.edit', compact('paciente'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Paciente $paciente
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Paciente $paciente)
    {
        request()->validate(Paciente::$rules);

        $paciente->update($request->all());

        return redirect()->route('pacientes.index')
            ->with('success', 'Paciente actualizado satisfactoriamente');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $paciente = Paciente::find($id)->delete();

        return redirect()->route('pacientes.index')
            ->with('Eliminar', 'Ok');
    }
}
