<?php

namespace App\Http\Controllers;

use App\Models\Sanitario;
use Illuminate\Http\Request;
use PDF;
use Carbon\Carbon;

/**
 * Class SanitarioController
 * @package App\Http\Controllers
 */
class SanitarioController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $sanitarios = Sanitario::paginate(20);// número de registros a mostrar por página

        return view('sanitario.index', compact('sanitarios'))
            ->with('i', (request()->input('page', 1) - 1) * $sanitarios->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $sanitario = new Sanitario();
        return view('sanitario.create', compact('sanitario'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Sanitario::$rules);

        $sanitario = Sanitario::create($request->all());

        return redirect()->route('sanitarios.index')
            ->with('success', 'Sanitario creado satisfactoriamente.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $sanitario = Sanitario::find($id);

        return view('sanitario.show', compact('sanitario'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $sanitario = Sanitario::find($id);

        return view('sanitario.edit', compact('sanitario'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Sanitario $sanitario
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Sanitario $sanitario)
    {
        request()->validate(Sanitario::$rules);

        $sanitario->update($request->all());

        return redirect()->route('sanitarios.index')
            ->with('success', 'Sanitario actualizado satisfactoriamente');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $sanitario = Sanitario::find($id)->delete();
        
        return redirect()->route('sanitarios.index')
            ->with('Eliminar', 'Ok');
    }

    // para buscar un sanitario por nombre
    public function buscar(Request $request)
    {
       $sanitarios = Sanitario::where('nombre','like', '%'.$request->buscarSan.'%')->paginate(20);

        return view('sanitario.index', compact('sanitarios'))
       ->with('i', (request()->input('page', 1) - 1) * $sanitarios->perPage());

    
    }

    // para generar PDF listado de sanitarios
    public function createSanPDF()
    {
       $sanitarios = Sanitario::all();
       view()->share('sanitarios', $sanitarios);
       $pdf = PDF::loadView('sanitario.pdf',compact('sanitarios'))->setOptions(['defaultFont' => 'sans-serif']);
       return $pdf->download('sanitarios.pdf');

    }
}
